/* statusbar.c -- Handles statusbar and title.

 * Copyright (C) 1999 Yarick Rastrigin <yarick@relex.ru>
 *                    Steve Hill <sjhill@plutonium.net>
 *                    Dany de Bontridder <dany.db@tvd.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <gtk/gtk.h>
#include <glib.h>
#include <sys/stat.h>
#include <unistd.h>

#include "common.h"
#include "rq.h"
#include "addons.h"
#include "make_dir_list.h"

static guint statusbar_context;
static guint last_message_id = 0;

void
init_statusbar ()
{
  statusbar_context = gtk_statusbar_get_context_id (GTK_STATUSBAR (main_statusbar), "Main statusbar");
  putRequest (UPDATE_STATUS, NULL, NULL);
}

void
update_status ()
{
  gchar *hgc1 = g_malloc0 (256);
  GList *hGL1 = current_directory;
  UniversalItem *hUI1;
  FileInfo *hFI1;
  gint dirs = 0;
  gint files = 0;
  gint size = 0;
  gint selected = 0;
  gint selected_total = 0;
  for (; hGL1; hGL1 = hGL1->next)
    {
      hUI1 = (UniversalItem *) (hGL1->data);
      hFI1 = (FileInfo *) hUI1->data;
      switch (hUI1->type)
	{
	case FILE_LIST_DIR:
	  dirs++;
	  break;
	case FILE_LIST_FILE:
	  files++;
	  size += hFI1->info.st_size;
	  break;
	default:
	  files++;
	  break;
	};
      if (hFI1->selected)
	{
	  selected++;
	  if (hUI1->type == FILE_LIST_FILE)
	    selected_total += hFI1->info.st_size;
	};
    };
  if (!selected)
    g_snprintf (hgc1, 255, "Total %d dirs, %d bytes in %d files", dirs, size, files);
  else
    g_snprintf (hgc1, 255, "Total %d dirs, %d bytes in %d files. Selected %d byte(s) in %d items", dirs, size, files, selected_total, selected);

  if (last_message_id != 0)
    gtk_statusbar_remove (GTK_STATUSBAR (main_statusbar), statusbar_context, last_message_id);
  last_message_id =
    gtk_statusbar_push (GTK_STATUSBAR (main_statusbar), statusbar_context, hgc1);
  gtk_window_set_title (GTK_WINDOW (main_window), (gchar *) gvfs_get_current_dir ());
}
